<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label=" 方案ID " prop="schemeid">
        <el-input
          v-model="queryParams.schemeid"
          placeholder="请输入 方案ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 基线时间 " prop="baselinetime">
        <el-input
          v-model="queryParams.baselinetime"
          placeholder="请输入 基线时间 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 触发条件 " prop="triggerornot">
        <el-input
          v-model="queryParams.triggerornot"
          placeholder="请输入 触发条件;0.无 1.有 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 机构ID " prop="orgid">
        <el-input
          v-model="queryParams.orgid"
          placeholder="请输入 机构ID "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label=" 是否为主路径 " prop="ismain">
        <el-input
          v-model="queryParams.ismain"
          placeholder="请输入 是否为主路径 "
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['smartor:schemetriggerscene:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['smartor:schemetriggerscene:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['smartor:schemetriggerscene:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['smartor:schemetriggerscene:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="schemetriggersceneList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label=" 自增ID " align="center" prop="id" />
      <el-table-column label=" 方案ID " align="center" prop="schemeid" />
      <el-table-column label=" 基线时间 " align="center" prop="baselinetime" />
      <el-table-column label=" 触发条件 " align="center" prop="triggerornot" />
      <el-table-column label=" 是否为主路径 " align="center" prop="ismain" />
      <el-table-column label=" 机构ID " align="center" prop="orgid" />       
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:schemetriggerscene:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:schemetriggerscene:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改方案触发场景对话框 -->
    <el-dialog :title="title" :visible.sync="open" :show-close="true" :close-on-click-modal="false" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label=" 方案ID " prop="schemeid">
          <el-input v-model="form.schemeid" placeholder="请输入 方案ID " />
        </el-form-item>
        <el-form-item label=" 基线时间 " prop="baselinetime">
          <el-input v-model="form.baselinetime" placeholder="请输入 基线时间;1.加入后 2.出院后 3.就诊后 4.入院后 5.手术前 6.手术后 7.开药前 8.检验申请后 9.检验完成后 10.检查申请后 11.检查完成后 12.事件发生后 13.基线日期后 " />
        </el-form-item>
        <el-form-item label=" 触发条件 " prop="triggerornot">
          <el-input v-model="form.triggerornot" placeholder="请输入 触发条件;0.无 1.有 " />
        </el-form-item>
        <el-form-item label=" 机构ID " prop="orgid">
          <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
        </el-form-item>
        <el-form-item label=" 删除标记 " prop="delFlag">
          <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
        </el-form-item>
        <el-form-item label=" 是否为主路径 " prop="ismain">
          <el-input v-model="form.ismain" placeholder="请输入 是否为主路径;0.否 1.是 " />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listSchemetriggerscene, getSchemetriggerscene, delSchemetriggerscene, addSchemetriggerscene, updateSchemetriggerscene } from "@/api/smartor/schemetriggerscene";

export default {
  name: "Schemetriggerscene",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 方案触发场景表格数据
      schemetriggersceneList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        schemeid: null,
        baselinetime: null,
        triggerornot: null,
        orgid: null,
        isupload: null,
        uploadTime: null,
        ismain: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询方案触发场景列表 */
    getList() {
      this.loading = true;
      listSchemetriggerscene(this.queryParams).then(response => {
        this.schemetriggersceneList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        schemeid: null,
        baselinetime: null,
        triggerornot: null,
        orgid: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        ismain: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加方案触发场景";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getSchemetriggerscene(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改方案触发场景";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateSchemetriggerscene(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addSchemetriggerscene(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除方案触发场景编号为"' + ids + '"的数据项？').then(function() {
        return delSchemetriggerscene(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/schemetriggerscene/export', {
        ...this.queryParams
      }, `schemetriggerscene_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
